tests/hghave.py
changeset 46177 0c320e6032f1
parent 46163 ebcc52046096
child 46264 7149fb17ff72
--- a/tests/hghave.py	Sat Dec 19 12:01:58 2020 +0900
+++ b/tests/hghave.py	Sat Dec 19 12:07:24 2020 +0900
@@ -594,8 +594,8 @@
 @check("clang-format", "clang-format C code formatter")
 def has_clang_format():
     m = matchoutput('clang-format --version', br'clang-format version (\d+)')
-    # style changed somewhere between 4.x and 6.x
-    return m and int(m.group(1)) >= 6
+    # style changed somewhere between 10.x and 11.x
+    return m and int(m.group(1)) >= 11
 
 
 @check("jshint", "JSHint static code analysis tool")